@@ -277,8 +277,8 @@ Run prancer for a list of snapshots
     args.opath = None
     if args.db and args.db.upper() == REMOTE:
         from processor.helper.utils.compliance_utils import create_container_compliance, get_api_server, \
-            get_collection_api
-        from processor.helper.httpapi.http_utils import http_get_request, http_post_request
+            get_collection_api, get_validate_token_api
+        from processor.helper.httpapi.http_utils import http_get_request, http_json_post_request
         remoteValid = False
         if not args.gittoken:
             args.gittoken = os.environ['GITTOKEN'] if 'GITTOKEN' in os.environ else None
@@ -287,21 +287,33 @@ Run prancer for a list of snapshots
         if args.apitoken and args.gittoken:
             apiserver = get_api_server(args.env, args.company)
             if apiserver:
-                collectionUri = get_collection_api(apiserver, args.container)
-                hdrs = {
-                    "Authorization": "Bearer %s" % args.apitoken,
-                    "Content-Type": "application/json"
-                }
-                status, data = http_get_request(collectionUri, headers=hdrs)
-                if status and isinstance(status, int) and status == 200:
-                    if 'data' in data:
-                        collectionData = data['data']
-                        opath = create_container_compliance(args.container, collectionData)
-                        if opath:
-                            remoteValid = True
-                            args.remote = True
-                            args.opath = opath
-                            args.db = NONE
+                validationUri = get_validate_token_api(apiserver)
+                if validationUri:
+                    postdata = {
+                        "token": args.apitoken,
+                        "customer_id": "customer118"
+                    }
+                    hdrs = {
+                        "Content-Type": "application/json"
+                    }
+                    status, data = http_json_post_request(validationUri, postdata, headers=hdrs, name='API TOKEN')
+                    if status and isinstance(status, int) and status == 200:
+                        args.apitoken = data['data']['token']
+                        collectionUri = get_collection_api(apiserver, args.container)
+                        hdrs = {
+                            "Authorization": "Bearer %s" % args.apitoken,
+                            "Content-Type": "application/json"
+                        }
+                        status, data = http_get_request(collectionUri, headers=hdrs)
+                        if status and isinstance(status, int) and status == 200:
+                            if 'data' in data:
+                                collectionData = data['data']
+                                opath = create_container_compliance(args.container, collectionData)
+                                if opath:
+                                    remoteValid = True
+                                    args.remote = True
+                                    args.opath = opath
+                                    args.db = NONE
         if not remoteValid:
             msg = "Check the remote configuration viz env, apitoken, gittoken, company, exiting!....."
             console_log(msg, currentframe())
@@ -494,7 +506,9 @@ Run prancer for a list of snapshots
 
     # if args.remote:
     #     from processor.helper.utils.compliance_utils import upload_compliance_results
+    #     logger.info("Uploading data....")
     #     upload_compliance_results(args.container, args.opath, args.env, args.company, args.apitoken)
+
     return retval
 
 
